@@ -29,7 +29,7 @@ class SharePointAPI:
         username = credentials['username']
         password = credentials['password']
         sharepoint_url = credentials['sharepoint_url']
-        proxies = credentials['proxies']
+        proxies = {} if 'proxies' not in credentials else credentials['proxies']
 
         sharepoint_api = object.__new__(SharePointAPI)
         sharepoint_api.__init__(username, password, sharepoint_url, proxies)
